@@ -37,7 +37,7 @@ def wget(url, save=None, timeout=5, **kwargs):
     """
     import requests
 
-    with log.progress("Downloading '%s'" % url, rate=0.1) as w:
+    with log.progress("Downloading %r" % url, rate=0.1) as w:
         w.status("Making request...")
 
         response = requests.get(url, stream=True, timeout=timeout, **kwargs)
